import React, {useState} from 'react';
import {
  TextInput,
  View,
  Dimensions,
  StyleSheet,
  Pressable,
  Image,
} from 'react-native';
import tw from 'tailwind-react-native-classnames';
import searchIcon from '../assets/icons/search.png';

const width = Dimensions.get('window').width;
const Search = ({
  placeholder,
  textAlign,
  direction,
  onChange,
  value,
}) => {
  const styles = StyleSheet.create({
    inputStyle: {
      fontSize: width / 30,
      color: '#000',
      borderWidth: 0.5,
      borderColor: '#DBDBDB',
      paddingVertical: 16,
      paddingHorizontal: 10,
      direction: direction,
      textAlign: textAlign,
      backgroundColor: '#F9F9F9',
    },
  });
  return (
    <View style={[{marginTop: 18}, tw.style('w-full relative')]}>
      <TextInput
        style={[styles.inputStyle, tw.style('rounded-md')]}
        onChangeText={text => onChange(text)}
        placeholder={placeholder}
        placeholderTextColor={'#cccccc'}
        value={value}
      />
      <Pressable style={tw.style('absolute left-3 top-0 transform inset-y-4')}>
        <Image source={searchIcon} style={[{width: 20, height: 20}]} />
      </Pressable>
    </View>
  );
};

export default Search;

Search.defaultProps = {
  direction: 'rtl',
  textAlign: 'right',
};