import React from 'react';
import {View, Text, Image, Dimensions} from 'react-native';
import tw from 'tailwind-react-native-classnames';
import {connect} from 'react-redux';

import bookFeatureIcon from '../assets/bookFeatureIcon.png';
import packageFeatureIcon from '../assets/packageFeatureIcon.png';
import testFeatureIcon from '../assets/testFeatureIcon.png';
import videoFeatureIcon from '../assets/videoFeatureIcon.png';

const width = Dimensions.get('window').width;

function Features({features}) {
  return (
    <View style={tw.style('w-full flex flex-row flex-wrap px-4')}>
      {features.map((feature, index) => (
        <Feature feature={feature} key={index} />
      ))}
    </View>
  );
}

const Feature = ({feature}) => {
  return (
    <View style={tw.style('flex flex-col w-1/2 items-start mb-5 pr-4')}>
      <View
        style={[
          tw.style('rounded-md flex justify-center items-center'),
          {
            backgroundColor: feature.backgroundColor,
            width: width / 7 + 10,
            height: width / 7 + 10,
          },
        ]}>
        <Image source={feature.icon} style={[{width: 40, height: 35}]} />
      </View>
      <Text
        style={[
          tw.style('font-semibold mt-3'),
          {color: feature.color, fontSize: width / 29},
        ]}>
        {feature.title}
      </Text>
      <Text
        style={[
          tw.style('font-light mt-1 text-left'),
          {color: '#333333', fontSize: width / 36},
        ]}>
        {feature.text}
      </Text>
    </View>
  );
};

const mapStateToProps = state => ({
  // features: state.publicApi.home?.features,
});
export default connect(mapStateToProps, {})(Features);

Features.defaultProps = {
  features: [
    {
      icon: bookFeatureIcon,
      backgroundColor: '#FFFDC4',
      color: '#C0C700',
      title: 'کتاب‌های تعاملی',
      text: 'قابلیت امتیاز دهی به مطالب از جمله امکانات این سامانه می باشد تا به جامعه هدف کارکنان کمک نماید',
    },
    {
      icon: videoFeatureIcon,
      backgroundColor: '#A1DDFF',
      color: '#196EC0',
      title: '',
      title: 'ویدئوهای مربوط به هر درس',
      text: 'انتخاب رنگ در حوزه طراحی کار بسیار عجیبی است و کاربران همه روزه با آن دسته پنجه نرم می کنند',
    },
    {
      icon: testFeatureIcon,
      backgroundColor: '#C4FFF7',
      color: '#06A38E',
      title: 'آزمون ',
      text: 'این پلتفرم می تواند تاریخ جشن تولد خود شما، دوستان شما و حتی خانواده شما را به شما یادآوری نمایید',
    },
    {
      icon: packageFeatureIcon,
      backgroundColor: '#FFC4EB',
      color: '#930362',
      title: 'پکیج ‌های آموزشی ',
      text: 'همه پایه های تحصیلی باید توسط کاربران انتخاب شود تا به آنها اینکار را یادآوری نماید',
    },
  ],
};
