import React, {useState} from 'react';
import {View, Text, Image, ActivityIndicator, Dimensions, TextInput, TouchableHighlight} from 'react-native';
import Logo from '../../assets/images/logo.png';
import IranFlag from "./components/IranFlag";
import {digitToEn, digitToPersian} from "../../utils";
import services from "./services";
import {asyncAwesomeAlert} from "../../utils/AsyncWrappers";

const {width, height} = Dimensions.get('window');
let faNums = ['۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹', '۰']

function Login(props) {

  const [phone, setPhone] = useState('');
  const [loading, setLoading] = useState(false)

  const onChangePhone = (value) => {
    let items = digitToPersian(value).split('');
    for (let item of items) {
      if (!faNums.includes(item)) {
        return
      }
    }
    setPhone(digitToPersian(value));
  }

  const checkPhoneNumber = () => {
    return phone.split('').length === 9;
  }

  const submit = async () => {
    setLoading(true)
    if (!checkPhoneNumber()) {
      setLoading(false)
      return asyncAwesomeAlert('خطا', 'شماره وارد شده اشتباه است', {showCancelButton: false});
    }
    let res = await services.getSmsCode({
      cellphone: '09' + digitToEn(phone)
    })
    if (res.ok) {
      setLoading(false)
      props.navigation.navigate('Otp', {phone: '09' + digitToEn(phone)});
    }
    setLoading(false)
  }

  return (
    <View style={{
      flex: 1,
      justifyContent: 'center',
      alignItems: 'center',
      backgroundColor: 'white'
    }}>
      <Image source={Logo} style={{
        width: width * 0.7,
        height: width * 0.7 / 2.09,
      }}  />
      <Text style={{
        width: width,
        paddingHorizontal: 10,
        marginTop: 20,
        fontSize: 20,
        textAlign: 'right',
      }}>{'دانوین'}</Text>
      <Text style={{
        width: width,
        paddingHorizontal: 10,
        marginTop: 10,
        fontSize: 14,
        color: '#6f7074',
        textAlign: 'right',
      }}>{'به دانوین خوش اومدی برای عضویت و ادامه شماره موبایلت رو وارد کن و روی گزینه ثبت بزن'}</Text>
      <View style={{
        width: width - 10,
        height: width / 8,
        borderRadius: 8,
        backgroundColor: '#f2f2f2',
        flexDirection: 'row',
        marginTop: 10,
        alignItems: 'center'
      }}>
        <IranFlag />
        <Text style={{
          // width: width / 7 - 15,
          fontSize: 18,
          marginLeft: 10,
          color: '#a2a2a2',
          textAlign: 'right',
          // marginRight: 5,
        }}>
          {'۰۹'}
        </Text>
        <TextInput
          style={{
            width: width / 1.5,
            color: '#a2a2a2',
            fontSize: 18
          }}
          maxLength={9}
          underlineColorAndroid={'transparent'}
          value={phone}
          onChangeText={text => onChangePhone(text)}
        />
      </View>
      <TouchableHighlight
        disabled={loading}
        style={{
        width: width - 10,
        height: width / 9,
        backgroundColor: '#6cbe44',
        alignItems: 'center',
        justifyContent: 'center',
        borderRadius: 10,
        marginTop: 15,
      }}
      onPress={() => submit()}>
        {loading ?
        <ActivityIndicator size={'small'} color={'white'}/>
          :
          <Text style={{
            color: 'white',
            fontSize: 18,
          }}>
            {'ادامه'}
          </Text>
        }
      </TouchableHighlight>
    </View>
  );
}

export default Login;
