import React from 'react';
import {View, Text, Dimensions, StyleSheet, ScrollView} from 'react-native';
import Book from './components/Book';
import {connect} from 'react-redux';
import tw from 'tailwind-react-native-classnames';
import b1Image from './assets/b1.png';
import _ from 'lodash';

const width = Dimensions.get('window').width;
const height = Dimensions.get('window').height;

const colors = {
  1: '#FFF700',
  4: '#FF0000',
  3: '#4CFF00',
  2: '#196EC0',
};

const status = {
  1: 'در حال پردازش',
  4: 'درخواست رد شد',
  3: 'تکمیل شد',
  2: 'ارسال شده',
};

function OrderDetails({order}) {
  return (
    <ScrollView
      contentContainerStyle={styles.contentContainerStyle}
      style={styles.container}>
      <View
        style={[
          tw.style(
            'flex flex-row-reverse w-full justify-between items-center p-3',
          ),
          {backgroundColor: '#EEF7FF'},
        ]}>
        <Text
          style={[
            tw.style('font-medium'),
            {fontSize: width / 32, color: '#20297B'},
          ]}>
          {_.join(['شماره سفارش:', order.number], ' ')}
        </Text>
        <View style={tw.style('flex flex-row-reverse items-center')}>
          <Text
            style={[
              tw.style('font-light'),
              {color: '#20297B', fontSize: width / 32},
            ]}>
            {status[order.status]}
          </Text>
          <View
            style={[
              tw.style('h-4 w-4 rounded-full mr-2'),
              {backgroundColor: colors[order.status]},
            ]}></View>
        </View>
      </View>
      <View
        style={[
          tw.style('w-full flex flex-row-reverse py-4'),
          {borderBottomWidth: 1, borderColor: '#86A0B933'},
        ]}>
        <Text
          style={[
            tw.style('font-medium'),
            {fontSize: width / 32, color: '#05335F'},
          ]}>
          آدرس تحویل:
        </Text>
        <Text
          style={[
            tw.style('flex-1 font-light text-right mr-2'),
            {fontSize: width / 32, lineHeight: 17, color: '#05335F'},
          ]}>
          {order.address}
        </Text>
      </View>
      <View
        style={[
          tw.style('w-full flex flex-row-reverse justify-between py-4'),
          {borderBottomWidth: 1, borderColor: '#86A0B933'},
        ]}>
        <View style={tw.style('flex flex-row-reverse')}>
          <Text
            style={[
              tw.style('font-medium'),
              {fontSize: width / 32, color: '#05335F'},
            ]}>
            مشخصات تحویل گیرنده:
          </Text>
          <Text
            style={[
              tw.style('font-light text-right mr-1'),
              {fontSize: width / 32, lineHeight: 15, color: '#05335F'},
            ]}>
            {order.name}
          </Text>
        </View>
        <View style={tw.style('flex flex-row-reverse')}>
          <Text
            style={[
              tw.style('font-medium'),
              {fontSize: width / 32, color: '#05335F'},
            ]}>
            شماره موبایل:
          </Text>
          <Text
            style={[
              tw.style('font-light text-right mr-1'),
              {fontSize: width / 32, lineHeight: 17, color: '#05335F'},
            ]}>
            {order.cellphone}
          </Text>
        </View>
      </View>
      <View
        style={[
          tw.style('w-full rounded-md flex flex-col p-4 items-end mt-2'),
          {backgroundColor: '#EEF6FF'},
        ]}>
        <Text
          style={[
            tw.style('font-medium'),
            {fontSize: width / 32, color: '#05335F'},
          ]}>
          {_.join(['کد تحویل', order.receiveCode], ' ')}
        </Text>
        <Text
          style={[
            tw.style('font-light text-right mt-2'),
            {fontSize: width / 32, lineHeight: 17, color: '#05335F'},
          ]}>
          این کد را پس از دریافت کالا، به مامور ارسال دانوین اعلام فرمایید
        </Text>
      </View>
      <View style={tw.style('w-full flex flex-column items-end')}>
        {order.items.map((item, index) => (
          <Book book={item} key={index} />
        ))}
      </View>
      <View
        style={[tw.style('w-full flex flex-row-reverse justify-between py-4')]}>
        <View style={tw.style('flex flex-row-reverse')}>
          <Text
            style={[
              tw.style('font-medium'),
              {fontSize: width / 32, color: '#05335F'},
            ]}>
            مبلغ سبد خرید:
          </Text>
          <Text
            style={[
              tw.style('font-light text-right mr-1'),
              {fontSize: width / 32, lineHeight: 15, color: '#05335F'},
            ]}>
            {_.join([order.shoppingCardPrice, 'تومان'], ' ')}
          </Text>
        </View>
        <View style={tw.style('flex flex-row-reverse')}>
          <Text
            style={[
              tw.style('font-medium'),
              {fontSize: width / 32, color: '#05335F'},
            ]}>
            تخفیف:
          </Text>
          <Text
            style={[
              tw.style('font-light text-right mr-1'),
              {fontSize: width / 32, lineHeight: 17, color: '#05335F'},
            ]}>
            {_.join([order.discountPrice, 'تومان'], ' ')}
          </Text>
        </View>
      </View>
      <View
        style={[
          tw.style('w-full flex flex-row-reverse justify-between py-4'),
          {borderBottomWidth: 1, borderColor: '#86A0B933'},
        ]}>
        <View style={tw.style('flex flex-row-reverse')}>
          <Text
            style={[
              tw.style('font-medium'),
              {fontSize: width / 32, color: '#05335F'},
            ]}>
            هزینه ارسال کالا:
          </Text>
          <Text
            style={[
              tw.style('font-light text-right mr-1'),
              {fontSize: width / 32, lineHeight: 15, color: '#05335F'},
            ]}>
            {_.join([order.sendPrice, 'تومان'], ' ')}
          </Text>
        </View>
        <View style={tw.style('flex flex-row-reverse')}>
          <Text
            style={[
              tw.style('font-medium'),
              {fontSize: width / 32, color: '#05335F'},
            ]}>
            جمع هزینه پرداختی:
          </Text>
          <Text
            style={[
              tw.style('font-light text-right mr-1'),
              {fontSize: width / 32, lineHeight: 17, color: '#05335F'},
            ]}>
            {_.join([order.totalPrice, 'تومان'], ' ')}
          </Text>
        </View>
      </View>
      <View
        style={[
          tw.style('w-full flex flex-row-reverse justify-between py-4'),
          {borderBottomWidth: 1, borderColor: '#86A0B933'},
        ]}>
        <View style={tw.style('flex flex-row-reverse')}>
          <Text
            style={[
              tw.style('font-medium'),
              {fontSize: width / 32, color: '#05335F'},
            ]}>
            نحوه پرداخت:
          </Text>
          <Text
            style={[
              tw.style('font-light text-right mr-1'),
              {fontSize: width / 32, lineHeight: 15, color: '#05335F'},
            ]}>
            {order.payMethod}
          </Text>
        </View>
        <View style={tw.style('flex flex-row-reverse')}>
          <Text
            style={[
              tw.style('font-medium'),
              {fontSize: width / 32, color: '#05335F'},
            ]}>
            شماره تراکنش:
          </Text>
          <Text
            style={[
              tw.style('font-light text-right mr-1'),
              {fontSize: width / 32, lineHeight: 17, color: '#05335F'},
            ]}>
            {order.transactionNumber}
          </Text>
        </View>
      </View>
      <View
        style={[tw.style('w-full flex flex-row-reverse justify-between py-4')]}>
        <View style={tw.style('flex flex-row-reverse')}>
          <Text
            style={[
              tw.style('font-medium'),
              {fontSize: width / 32, color: '#05335F'},
            ]}>
            تاریخ تحویل:
          </Text>
          <Text
            style={[
              tw.style('font-light text-right mr-1'),
              {fontSize: width / 32, lineHeight: 15, color: '#05335F'},
            ]}>
            {order.date}
          </Text>
        </View>
      </View>
    </ScrollView>
  );
}

const styles = StyleSheet.create({
  contentContainerStyle: {
    paddingBottom: 50,
    alignItems: 'flex-end',
  },
  container: {
    width: width,
    backgroundColor: 'white',
    flexDirection: 'column',
    paddingVertical: 5,
    paddingHorizontal: 10,
  },
});

export default OrderDetails;

OrderDetails.defaultProps = {
  order: {
    number: '535353523653',
    receiveCode: '300031',
    status: 2,
    items: [b1Image, b1Image],
    date: '1400/1/11',
    cost: '1.240.000',
    address:
      'تهران خیابان انقلاب حدفاصل ابوریحان و فلسطین بن بست سروش پلاک 2 واحد 12 شرقی',
    name: 'هومن عابدی',
    cellphone: '09121234568',
    shoppingCardPrice: '981.000',
    discountPrice: '12.000',
    sendPrice: '18.000',
    totalPrice: '18.000',
    payMethod: 'حضوری',
    transactionNumber: ' BS3194DNB98312',
  },
};
