import React from 'react';
import {
  View,
  Text,
  Dimensions,
  StyleSheet,
  Image,
  Pressable,
} from 'react-native';
import tw from 'tailwind-react-native-classnames';
import leftArrowIcon from '../assets/leftArrow.png';
import plusIcon from '../assets/plus.png';
import _ from 'lodash';

const width = Dimensions.get('window').width;
const height = Dimensions.get('window').height;

const colors = {
  1: '#FFF700',
  4: '#FF0000',
  3: '#4CFF00',
  2: '#196EC0',
};

const status = {
  1: 'در حال پردازش',
  4: 'درخواست رد شد',
  3: 'تکمیل شد',
  2: 'ارسال شده',
};

function Order({order}) {
  return (
    <View
      style={[
        tw.style('w-full flex flex-col rounded-md overflow-hidden my-3'),
        {borderWidth: 1, borderColor: '#EEF7FF'},
      ]}>
      <View
        style={[
          tw.style(
            'flex flex-row-reverse w-full justify-between items-center p-3',
          ),
          {backgroundColor: '#EEF7FF'},
        ]}>
        <Text
          style={[
            tw.style('font-medium'),
            {fontSize: width / 32, color: '#20297B'},
          ]}>
          {_.join(['شماره سفارش:', order.number], ' ')}
        </Text>
        <View style={tw.style('flex flex-row-reverse items-center')}>
          <Text
            style={[
              tw.style('font-light'),
              {color: '#20297B', fontSize: width / 32},
            ]}>
            {status[order.status]}
          </Text>
          <View
            style={[
              tw.style('h-4 w-4 rounded-full mr-2'),
              {backgroundColor: colors[order.status]},
            ]}></View>
        </View>
      </View>
      <View
        style={tw.style('w-full flex flex-row-reverse justify-between p-3')}>
        <View style={tw.style('flex flex-col')}>
          <View style={tw.style('flex flex-row-reverse mb-2')}>
            {order.items.length < 2
              ? order?.items?.map(item => (
                  <Image
                    source={item}
                    style={[
                      tw.style('rounded-md ml-1.5'),
                      {width: width / 5.8, height: height / 8},
                    ]}
                  />
                ))
              : order.items
                  ?.slice(0, 1)
                  ?.map(item => (
                    <Image
                      source={item}
                      style={[
                        tw.style('rounded-md ml-1.5'),
                        {width: width / 5.8, height: height / 8},
                      ]}
                    />
                  ))}
            {order.items.length >= 2 && (
              <View
                style={[
                  tw.style(
                    'flex flex-row-reverse items-center justify-center relative rounded-md overflow-hidden',
                  ),
                  {
                    width: width / 5.8,
                    height: height / 8,
                    backgroundColor: '#EBEBEB',
                  },
                ]}>
                {/* <Image
                  source={order.items[2]}
                  style={[tw.style('absolute left-0 top-0 h-full w-full z-10')]}
                /> */}
                <Image source={plusIcon} style={[tw.style('w-4 h-6 z-30')]} />
              </View>
            )}
          </View>
          <View style={[tw.style('bg-red-400')]}>
            <Text
              style={[
                tw.style('p-2 rounded-md text-center'),
                {
                  fontSize: width / 32,
                  backgroundColor: '#F0FFF1',
                  color: '#05335F',
                },
              ]}>
              {_.join(['کد تحویل:', order.receiveCode], ' ')}
            </Text>
          </View>
        </View>
        <View style={tw.style('flex flex-col items-center mr-4')}>
          <Text
            style={[
              tw.style('my-3'),
              {fontSize: width / 25, color: '#132F52'},
            ]}>
            {_.join(['جمع فاکتور:', order.cost], ' ')}
          </Text>
          <Pressable
            style={[
              tw.style('rounded-md flex flex-row-reverse justify-center px-5 py-3'),
              {borderWidth: 1, borderColor: '#1999C0'},
            ]}>
            <Text style={{fontSize: width / 28, color: '#1999C0'}}>
              جزئیات سفارش
            </Text>
            <Image
              source={leftArrowIcon}
              style={{width: 18, height: 18, marginRight: 10}}
            />
          </Pressable>
          <Text
            style={[
              tw.style('my-5'),
              {fontSize: width / 30, color: '#132F52'},
            ]}>
            {_.join(['تاریخ سفارش:', order.date], ' ')}
          </Text>
        </View>
      </View>
    </View>
  );
}

const styles = StyleSheet.create({
  contentContainerStyle: {
    paddingBottom: 50,
    alignItems: 'flex-end',
  },
  container: {
    width: width,
    backgroundColor: 'white',
    flexDirection: 'column',
    paddingVertical: 5,
    paddingHorizontal: 10,
  },
});

export default Order;
