import React, {useEffect, useState} from 'react'
import {
  View,
  Text,
  Image,
  TextInput,
  TouchableHighlight,
  Dimensions,
  StyleSheet,
  TouchableOpacity,
  ActivityIndicator
} from 'react-native';
import {connect} from 'react-redux';
import Logo from "../../assets/images/logo.png";
import IranFlag from "../Login/components/IranFlag";
import {digitToEn, digitToPersian} from "../../utils";
import services from "./services";
import AsyncStorage from "@react-native-async-storage/async-storage";
import {buildAction} from "../../reducers/DefaultReducer";
import {PROFILE_RECORD} from "../../actions/actionTypes";

const {width} = Dimensions.get('window')
let ref1;
let ref2;
let ref3;
let ref4;

let timer = 60;

const mapStateToProps = state => {
  return {
    profile: state.profile,
  }
}

function Otp(props) {
  let faNums = ['۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹', '۰']

  const [firstCode, setFirstCode] = useState('');
  const [secondCode, setSecondCode] = useState('');
  const [thirdCode, setThirdCode] = useState('');
  const [fourthCode, setFourthCode] = useState('');
  const [time, setTime] = useState(60);
  const [loading, setLoading] = useState(false);

  const checkValue = (value) => {
    return faNums.includes(digitToPersian(value));
  }

  const onChangeCode = (value, key) => {
    // if (!checkValue()) {
    //   return
    // }
    switch (key) {
      case '1':
        setFirstCode(digitToPersian(value));
        ref2.focus();
        break;
      case '2':
        setSecondCode(digitToPersian(value));
        ref3.focus();
        break;
      case '3':
        setThirdCode(digitToPersian(value));
        ref4.focus();
        break;
      case '4':
        setFourthCode(digitToPersian(value))
        submit();
        break;
    }
  }

  const getEnCode = () => {
    return Number(digitToEn(firstCode) + digitToEn(secondCode) + digitToEn(thirdCode) + digitToEn(fourthCode))
  }

  const submit = async () => {
    setLoading(true)
    let res = await services.sendOtpCode({
      cellphone: props.route.params.phone,
      otp: String(getEnCode()),
      applicationToken: "1",
      userToken: "1"
    })
    if (res.ok) {
      setLoading(false)
      await AsyncStorage.setItem('accessToken', res.data.accessToken);
      await AsyncStorage.setItem('refreshToken', res.data.refreshToken);
      let action = buildAction(PROFILE_RECORD);
      await props.dispatch(action({
        accessToken: res.data.accessToken,
        refreshToken: res.data.refreshToken,
        ...res.data.profile,
      }))
      props.navigation.reset({
        index: 0,
        routes: [{name: 'Home'}]
      })
    }
    setLoading(false)
  }

  useEffect(() => {
    let interval = setInterval(() => {
      if (time > 0) {
        setTime(timer - 1);
        timer -= 1;
      }
    }, 1000);
    let timeout = setTimeout(() => {
      clearInterval(interval)
    }, 60000)
    return () => {
      clearInterval(interval);
      clearTimeout(timeout)
    }
  }, []);

  return (
    <View style={{
      flex: 1,
      justifyContent: 'center',
      alignItems: 'center',
      backgroundColor: 'white'
    }}>
      <Image source={Logo} style={{
        width: width * 0.7,
        height: width * 0.7 / 2.09,
      }}  />
      <Text style={{
        width: width,
        paddingHorizontal: 10,
        marginTop: 20,
        fontSize: 20,
        textAlign: 'right',
      }}>{'دانوین'}</Text>
      <Text style={{
        width: width,
        paddingHorizontal: 10,
        marginTop: 10,
        fontSize: 14,
        color: '#6f7074',
        textAlign: 'right',
      }}>{`یک کد تائیدیه به شماره ${props.route.params.phone} ارسال شد. آن را در قسمت زیر وارد کنید`}</Text>
      <View style={{
        width: width - 10,
        height: width / 8,
        borderRadius: 8,
        flexDirection: 'row',
        marginTop: 10,
        alignItems: 'center',
        justifyContent: 'space-evenly'
      }}>
        <TextInput
          style={styles.input}
          underlineColorAndroid={'transparent'}
          value={firstCode}
          maxLength={1}
          ref={ref => ref1 = ref}
          onChangeText={text => onChangeCode(text, '1')}
        />
        <TextInput
          style={styles.input}
          underlineColorAndroid={'transparent'}
          value={secondCode}
          maxLength={1}
          ref={ref => ref2 = ref}
          onChangeText={text => onChangeCode(text, '2')}
        />
        <TextInput
          style={styles.input}
          underlineColorAndroid={'transparent'}
          value={thirdCode}
          maxLength={1}
          ref={ref => ref3 = ref}
          onChangeText={text => onChangeCode(text, '3')}
        />
        <TextInput
          style={styles.input}
          underlineColorAndroid={'transparent'}
          value={fourthCode}
          maxLength={1}
          ref={ref => ref4 = ref}
          onChangeText={text => onChangeCode(text, '4')}
        />
      </View>
      <TouchableOpacity
        disabled={loading}
        style={{
          width: width - 10,
          height: width / 9,
          backgroundColor: '#6cbe44',
          alignItems: 'center',
          justifyContent: 'center',
          borderRadius: 10,
          marginTop: 15,
        }}
        onPress={() => submit()}>
        {loading ?
          <ActivityIndicator color={'white'} size={'small'} /> :
          <Text style={{
            color: 'white',
            fontSize: 18,
          }}>
            {'ثبت'}
          </Text>
        }
      </TouchableOpacity>
      <View>
        <Text style={{marginTop: 30, textAlign: 'center'}}>
          {'زمان باقی مانده تا انقضای کد: ' + time}
        </Text>
        <TouchableOpacity
          style={{
            marginTop: 20,
          }}
          onPress={() => {
            props.navigation.reset({
              index: 0,
              routes: [{ name: 'Login' }],
            });
          }}>
          <Text style={{textAlign: 'center'}}>
            {'بازگشت به مرحله قبل و اصلاح شماره'}
          </Text>
        </TouchableOpacity>
      </View>
    </View>
  )
}

const styles = StyleSheet.create({
  input: {
    width: width / 13 * 2,
    height: width / 16 * 2,
    backgroundColor: '#a2a2a2',
    color: '#000',
    fontSize: 22,
    borderRadius: 8,
    textAlign: 'center'
  }
})

export default connect(mapStateToProps)(Otp);
