import {t} from 'i18next';
import React from 'react';
import {
  View,
  Text,
  Image,
  Dimensions,
  ScrollView,
  Pressable,
} from 'react-native';
import CustomPressable from '../../../components/Pressable';
import Description from './Description';
import LinkBox from './LinkBox';
import Comments from './Comments';
import Rates from './Rates';
import tw from 'tailwind-react-native-classnames';
import arrowMoreIcon from '../assets/arrowMore.png';

const width = Dimensions.get('window').width;
const height = Dimensions.get('window').height;

export default function Book({product}) {
  return (
    <ScrollView style={[tw.style('flex flex-col flex-1')]}>
      <View style={tw.style('flex flex-row-reverse')}>
        <View
          style={[
            tw.style('rounded-md'),
            {height: height / 5, width: width / 3.5},
          ]}>
          <Image
            source={{uri: product.imageUrl}}
            style={[tw.style('rounded-md h-full w-full')]}
          />
        </View>

        <View
          style={[
            tw.style('flex flex-col flex-1 justify-between items-end'),
            {
              paddingRight: 10,
            },
          ]}>
          <View style={tw.style('flex flex-col items-end')}>
            <Text
              style={{
                color: '#05335F',
                fontSize: width / 17,
                marginBottom: 5,
              }}>
              {product.name}
            </Text>
            <Text style={{color: '#196EC0', fontSize: width / 30}}>
              {product.grade}
            </Text>
          </View>
          <Text
            style={[
              tw.style('text-right w-full'),
              {color: '#323232', fontSize: width / 32},
            ]}>
            {product.text}
          </Text>
        </View>
      </View>
      <View
        style={tw.style(
          'flex flex-row-reverse items-center justify-around py-6',
        )}>
        <View>
          <Text
            style={{
              color: '#196EC0',
              textAlign: 'center',
              fontSize: width / 27,
            }}>
            {' '}
            {473 + '\n' + 'صفحه'}
          </Text>
        </View>
        <View
          style={{backgroundColor: '#196EC055', height: 20, width: 2}}></View>
        <View>
          <Text
            style={{
              color: '#196EC0',
              textAlign: 'center',
              fontSize: width / 27,
            }}>
            {' '}
            {'فیزیکی- دیجیتالی - ویدئو' + '\n' + 'در دسترس'}
          </Text>
        </View>
        <View
          style={{backgroundColor: '#196EC055', height: 20, width: 2}}></View>
        <View>
          <Text
            style={{
              color: '#196EC0',
              textAlign: 'center',
              fontSize: width / 27,
            }}>
            {' '}
            {4.8 + '\n' + 'امتیاز'}
          </Text>
        </View>
      </View>
      <View style={'flex flex-col mt-3'}>
        <Text
          style={[
            tw.style('w-full text-right font-medium'),
            {color: '#196EC0', fontSize: width / 26},
          ]}>
          نسخه محصول را انتخاب کنید
        </Text>
        <View style={tw.style('flex justify-between')}></View>
      </View>
      <View
        style={tw.style(
          'flex flex-row-reverse justify-between flex-wrap py-3',
        )}>
        <CustomPressable
          title={'نسخه فیزیکی'}
          backgroundColor="transparent"
          color={'#196EC0'}
          border={{color: '#196EC0', width: 1}}
          width={'49%'}
        />
        <CustomPressable
          title={'نسخه دیجیتال'}
          backgroundColor="transparent"
          color={'#196EC0'}
          border={{color: '#196EC0', width: 1}}
          width={'49%'}
        />
        <CustomPressable
          title={'خرید با قیمت 245.000 تومان'}
          backgroundColor="#196EC0"
          color={'white'}
          border={{color: '#196EC0', width: 0}}
          width={'65%'}
        />
        <CustomPressable
          title={'مشاهده نمونه'}
          backgroundColor="transparent"
          color={'#196EC0'}
          border={{color: '#196EC0', width: 1}}
          width={'33%'}
        />
        <Pressable
          style={[
            tw.style(
              'w-full rounded-md flex flex-row justify-center items-center py-3.5',
            ),
            {backgroundColor: '#196EC01a'},
          ]}>
          <Image
            source={arrowMoreIcon}
            style={{width: 12, height: 16, marginRight: 10}}
          />

          <Text
            style={[tw.style(''), {color: '#275077', fontSize: width / 27}]}>
            مشاهده دوره ویدئویی این محصول
          </Text>
        </Pressable>
      </View>
      <Description description={product.description} />
      <LinkBox title="مشخصات محصول" path="" />
      <LinkBox title="نقد بررسی و توضیحات تکمیلی محصول" path="" />
      <LinkBox title="پرسش و پاسخ" path="" />
      <View
        style={tw.style(
          'flex flex-row-reverse justify-between items-center my-4',
        )}>
        <Text
          style={[
            {fontSize: width / 25, color: '#275077'},
            tw.style('semibold'),
          ]}>
          امتیازات و نظرات
        </Text>
        <Image
          source={arrowMoreIcon}
          style={{width: 12, height: 16, marginRight: 10}}
        />
      </View>
      <Rates rates={product.rates} />
      <Comments comments={product.comments} />
    </ScrollView>
  );
}
