import React, {useState} from 'react';

import {View, ScrollView, StyleSheet, Dimensions} from 'react-native';
import tw from 'tailwind-react-native-classnames';

import {connect} from 'react-redux';
import Book from './components/Book';
import Video from './components/Video';
import Search from '../../components/Search';
import Select from '../../components/Select';

function Products({grades, productTypes}) {
  const [productType, setProductType] = useState('');
  const [grade, setGrade] = useState('');
  const [search, setSearch] = useState('');
  const onChange = (name, value) => {};
  return (
    <ScrollView
      contentContainerStyle={styles.contentContainerStyle}
      style={styles.container}>
      <Search
        value={search}
        onChange={setSearch}
        placeholder={'نام کتاب یا دوره را جستجو کنید'}
      />
      <View
        style={[
          tw.style('flex flex-1 flex-row justify-between items-center'),
          {marginTop: 10, width: '100%'},
        ]}>
        <Select
          defaultValue={'کتاب فیزیکی'}
          value={productType}
          onChange={setProductType}
          options={productTypes}
          width={'48%'}
        />
        <Select
          defaultValue={'همه پایه'}
          value={grade}
          onChange={setGrade}
          options={grades}
          width={'48%'}
        />
      </View>
      <View
        style={tw.style(
          'flex flex-1 w-full py-5 flex-row flex-wrap justify-between bg-white',
        )}>
        {[0, 1, 2, 3, 4, 5, 6, 7].map((item, i) =>
          productType === 'ویدئوها' ? <Video /> : <Book />,
        )}
      </View>
    </ScrollView>
  );
}

const styles = StyleSheet.create({
  contentContainerStyle: {
    paddingBottom: 50,
  },
  container: {
    width: Dimensions.get('window').width,
    backgroundColor: 'white',
    flexDirection: 'column',
    paddingVertical: 5,
    paddingHorizontal: 10,
  },
});

export default Products;

Products.defaultProps = {
  grades: [
    'پیش دبستان',
    'اول',
    'دوم',
    'سوم',
    'چهارم',
    'پنجم',
    'ششم',
    'هفتم',
    'هشتم',
    'نهم',
    'دهم',
    'یازدهم',
    'دوازدهم',
  ],
  productTypes: ['کتاب فیزیکی', 'کتاب دیجیتال', 'ویدئوها', 'اشتراک'],
};
