import React from 'react';
import {
  View,
  Text,
  ScrollView,
  SafeAreaView,
  Image,
  Dimensions,
} from 'react-native';
import {connect} from 'react-redux';
import tw from 'tailwind-react-native-classnames';
// import Content from './Content';
// import Scanner from './Scanner';
import Voice from './Content/Voice';
import Video from './Content/Video';
import PPT from './Content/PPT';
import PDF from './Content/PDF';
import Links from './Content/Links';

import bookmarkIcon from '../../assets/icons/bookmark.png';

const width = Dimensions.get('window').width;
function QR({data}) {
  return (
    <SafeAreaView>
      <ScrollView>
        <View style={tw.style('flex flex-1 flex-col px-3')}>
          <View
            style={tw.style(
              'flex w-full flex-row-reverse justify-between py-3',
            )}>
            <View style={tw.style('flex flex-row-reverse')}>
              <Image
                source={{uri: 'https://dnvn.ir/api/v1/file/2094'}}
                style={[tw.style('rounded'), {width: width / 5, height: 120}]}
              />
              <View
                style={tw.style('flex flex-column items-end self-end pr-3')}>
                <Text style={tw.style('text-md text-green-500 font-semibold')}>
                  {data.name}
                </Text>
                <Text
                  style={tw.style('text-xs text-gray-500 font-normal mt-1')}>
                  {data.grade}
                </Text>
                <Text
                  style={tw.style('text-xs text-gray-500 font-normal mt-1')}>
                  شما در حال مطالعه{' '}
                  <Text
                    style={tw.style('text-xs text-blue-500 font-medium mt-1')}>
                    {'صفحه' + ' ' + data.page}
                  </Text>{' '}
                  هستید.
                </Text>
                <Text
                  style={tw.style('text-xs text-gray-500 font-normal mt-1')}>
                  پیشرفت شما در مطالعه کتاب{' '}
                  <Text style={tw.style('text-xs text-green-500 font-medium')}>
                    {data.percent + '' + 'درصد'}
                  </Text>{' '}
                  میباشد.
                </Text>
              </View>
            </View>
            <Image source={bookmarkIcon} style={{width: 27, height: 33}} />
          </View>
          {data.voice && (
            <Voice name={data.voice.name} file={data.voice.file} />
          )}
          {
            data.video && <Video name={data.video.name} file={data.voice.file} />
          }
          {
            data.ppt && <PPT name={data.ppt.name} file={data.ppt.file} />
          }
          {
            data.pdf && <PDF name={data.ppt.name} file={data.ppt.file} />
          }
          {
            data.links && <Links links={data.links} />
          }
        </View>
      </ScrollView>
    </SafeAreaView>
  );
}

export default QR;

QR.defaultProps = {
  data: {
    name: 'ریاضیات گسسته خیلی پیشرفته',
    grade: 'پایه هفتم ابتدایی',
    page: '67',
    percent: '62',
    voice: {name: 'استاد رضایی: فصل پنجم توضیح در مورد آتش فشان ها', file: 1},
    video: {name: 'ویدئوی آزمایش آتشفشان سرکه ای', file: 1},
    pdf: {name : 'فایل پاورپوینت ارائه درس آتشفشان ها', file: 1},
    ppt: {name: 'فایل پاورپوینت ارائه درس آتشفشان ها', file: 1},
    links: [ "وبسایت آموزشی دانوین" , "وبسایت رسمی مدیریت راهبردی کشور", "سازمان تبلیغات صنایع سبک " ]
  },
};
