import React, {useState} from 'react';
import {
  View,
  Text,
  ScrollView,
  Dimensions,
  StyleSheet,
  Pressable,
  Image
} from 'react-native';
import Product from './components/Product';
import Code from './components/Code';
import CustomPressable from '../../components/Pressable';
import tw from 'tailwind-react-native-classnames';
import alertIcon from './assets/alert.png';

import {connect} from 'react-redux';

const width = Dimensions.get('window').width;

const PriceStatus = ({name, value, type}) => {
  return (
    <View style={tw.style('w-full flex flex-row-reverse justify-between py-2')}>
      <Text
        style={[
          tw.style('font-light'),
          {fontSize: width / 27, color: '#132F52'},
        ]}>
        {name}
      </Text>
      <Text
        style={[
          tw.style('font-normal'),
          {
            color: type === 'error' ? '#F1420D' : '#246E8A',
            fontSize: width / 27,
          },
        ]}>
        {value}
      </Text>
    </View>
  );
};

function ShoppingCart({}) {
  return (
    <ScrollView
      contentContainerStyle={styles.contentContainerStyle}
      style={styles.container}>
      {[0, 1].map((product, index) => (
        <Product key={index} product={product} />
      ))}
      <Code />
      <View
        style={tw.style(
          'flex flex-col w-full border-t py-2 border-gray-300 border-b mt-6',
        )}>
        <PriceStatus name="مبلغ سبد خرید" value="265000 تومان" type="normal" />
        <PriceStatus name="میزان تخفیف" value="0 تومان" type="error" />
        <PriceStatus
          name="مالیات بر ارزش افزوده"
          value="0 تومان"
          type="error"
        />
      </View>
      <View
        style={tw.style(
          'flex flex-row-reverse justify-between items-center w-full py-3',
        )}>
        <Text style={[tw.style('font-medium'), {fontSize: width / 25}]}>
          جمع کل سبد خرید
        </Text>
        <Text
          style={[
            tw.style('font-medium'),
            {fontSize: width / 27, color: '#246E8A'},
          ]}>
          235.000 تومان
        </Text>
      </View>
      <Pressable
        style={[
          tw.style('w-full rounded-md flex flex-row justify-end items-center py-3.5 px-3 my-5'),
          {backgroundColor: '#196EC01a'},
        ]}>
        <Text style={[tw.style(''), {color: '#275077', fontSize: width / 30}]}>
          هزینه ارسال کالا پس از تعیین محل آدرس مشخص می‌شود
        </Text>
        <Image source={alertIcon} style={{width: 18, height: 18, marginLeft : 5}} />
      </Pressable>
      <CustomPressable
        title={'ادامه فرایند خرید'}
        backgroundColor="#196EC0"
        color={'white'}
        border={{color: '#196EC0', width: 0}}
        width={'100%'}
      />
    </ScrollView>
  );
}

export default ShoppingCart;

const styles = StyleSheet.create({
  contentContainerStyle: {
    paddingBottom: 50,
  },
  container: {
    width: Dimensions.get('window').width,
    backgroundColor: 'white',
    flexDirection: 'column',
    paddingVertical: 5,
    paddingHorizontal: 10,
  },
});
