import {Alert} from 'react-native';
import {toastMessage} from '../../utils/message';
import {
  restartApp,
  getToken,
  deviceHeaders,
  getUrl,
  isUnexpected,
  renewTokenHandler,
  resetApp,
  networkAlert,
  unexpectedAlert,
} from './utils';
import FetchRetry from './fetch-retry';
import {asyncApiAwesomeAlert} from '../../utils/AsyncWrappers';

const fetchRetry = FetchRetry(fetch, {});
let deviceInfo;

export async function fetchApi(
  endPoint,
  payload = {},
  method = 'GET',
  headers = {},
  isS = false,
  splash = false,
  dev = 'production',
) {
  var timeout = setTimeout(() => {
    console.log(endPoint, ' TIMEOUT ');
    asyncApiAwesomeAlert('خطای ارتباط', '. لطفا اینترنت خود را بررسی کنید .').then(
      async () => await fetchApi(endPoint, payload, method, headers, isS),
    );
  }, 30000);
  if (!deviceInfo) {
    deviceInfo = await deviceHeaders();
    if (!deviceInfo) {
      deviceInfo = [];
    }
  }
  let options = {
    method,
    headers: {
      Accept: 'application/json;charset=utf-8',
      'Content-Type': 'application/json;charset=utf-8',
      Authorization: await getToken(),
      ...deviceInfo,
      ...headers,
    },
  };
  if (['POST', 'PUT'].includes(method)) {
    options.body = JSON.stringify(payload);
  }
  console.log('===========================')
  console.log(await getUrl(endPoint, dev))
  console.log(options)
  console.log('===========================')
  try {
    // console.log('req', await getUrl(endPoint), options)
    let res = await fetchRetry(await getUrl(endPoint, dev), options);

    clearTimeout(timeout);
    let statusCode = res.status;
    // console.log('RES', { statusCode, url: await getUrl(endPoint) })
    if (isUnexpected(statusCode)) {
      console.log('unexpected', await res.json());
      console.log('RES-unexpected', {statusCode, url: await getUrl(endPoint)});
      let check = await unexpectedAlert();

      return await fetchApi(
        endPoint,
        payload,
        method,
        headers,
        isS,
        false,
        true,
      );
    }
    let {data, error, status} = await res.json();
    if (res.ok) {
      return data;
    }
    if (!res.ok) {
      // if (data.hasOwnProperty('message')) {
      //   toastMessage(data.message);
      // }
      console.log('=====================')
      console.log(statusCode)
      console.log(data)
      console.log(error)
      console.log('=====================')
      if (statusCode === 403) {
        console.log('req-401', await getUrl(endPoint), options);

        return resetApp();
      }
      if (statusCode === 401) {
        let checkRenew = await renewTokenHandler();
        if (!checkRenew.ok && checkRenew.restart) {
          console.log('req-401', await getUrl(endPoint), options);

          resetApp();
        } else if (!checkRenew.ok) {
          console.log('req-401', await getUrl(endPoint), options);

          restartApp();
        }
        return await fetchApi(endPoint, payload, method, headers, isS, splash);
      }
      if (statusCode === 400) {
        return error;
      }
      return data;
    }
  } catch (err) {
    clearTimeout(timeout);
    console.log('catch', endPoint, err);
    // global.globalAlert({
    //   show: true
    // })
    let check = await networkAlert();
    return await fetchApi(endPoint, payload, method, headers, isS);
  }
}
/**
 *  next version of fetch API
 * @param {String} endPoint
 * @param {Object} options
 * @param {string} options.method
 * @param {string} options.payload
 * @param {string} options.headers
 * @param {Boolean} options.splash
 */
export async function nextFetchApi(endPoint, options = {}) {
  let {payload, method, headers, isS, splash} = options;
  try {
    let res = await fetchApi(endPoint, payload, method, headers, isS, splash);
    return {
      ok: true,
      data: res,
    };
  } catch (error) {
    return {
      ok: false,
      data: error,
    };
  }
}
