/* global fetch */

import apiConfig from './config';
import {
  AsyncStorage,
  Alert,
  AlertIOS,
  Platform,
  ToastAndroid,
} from 'react-native';
import {toastMessage} from '../../utils/message';

import RNRestart from 'react-native-restart';
import config from './config';
import Refresh from './fetch-retry';
import FetchRetry from './fetch-retry';
let fetchRetry = FetchRetry(fetch, {});

function restartApp() {
  AsyncStorage.setItem('UID_USER', JSON.stringify({}), () => {
    RNRestart.Restart();
  });
}

export function fetchApi(
  endPoint,
  payload = {},
  method = 'GET',
  headers = {},
  isS = false,
  splash = false,
) {
  return new Promise((resolve, reject) => {
    var timeout = setTimeout(() => {
      console.log(endPoint, ' TIMEOUT ');
      Alert.alert('خطای ارتباط', 'خطایی ارتباط با سرور پیش امده .', [
        {
          text: 'تلاش مجدد',
          onPress: () =>
            resolve(fetchApi(endPoint, payload, method, headers, isS)),
        },
      ]);
    }, 10000);

    AsyncStorage.getItem('UID_USER', (err, result) => {
      var tokens = '';
      var refreshTokens = '';
      var userDATA = JSON.parse(result);
      var headrsRequest = {};

      if (
        userDATA != null &&
        userDATA.token != null &&
        userDATA.token != '' &&
        isS
      ) {
        tokens = userDATA.token;

        refreshTokens = userDATA.refresh_token;
        headers = {
          Authorization: 'Bearer ' + tokens,
        };
      }

      if (method === 'POST' || method === 'PUT') {
        headrsRequest = {
          method: method,
          headers: {
            Accept: 'application/json;charset=utf-8',
            'Content-Type': 'application/json;charset=utf-8',
            ...headers,
          },
          body: JSON.stringify(payload),
        };
      } else {
        headrsRequest = {
          method: method,
          headers: {
            Accept: 'application/json;charset=utf-8',
            'Content-Type': 'application/json;charset=utf-8',
            ...headers,
          },
        };
      }

      AsyncStorage.getItem('SPLASH_DATA', (err, result) => {
        var splashDATA = JSON.parse(result);

        var baseUrl;

        if (endPoint.includes('splash')) {
          baseUrl = apiConfig.splash;
        } else {
          var baseUrl = splashDATA.base_urls.backend + '/v1.1';
        }

        fetchRetry(`${baseUrl}${endPoint}`, headrsRequest)
          .then(response => {
            const statusCode = response.status;
            const data = response.json();
            return Promise.all([statusCode, data]);
          })
          .then(([statusCode, data]) => {
            console.log(baseUrl + endPoint, statusCode, data);
            if (data.hasOwnProperty('message')) {
              toastMessage(data.message);
            }

            if (statusCode === 403) {
              clearTimeout(timeout);
              restartApp();
            }

            if (statusCode === 401) {
              clearTimeout(timeout);

              var dataaaaa = {
                method: 'POST',
                body: JSON.stringify({
                  refresh_token: refreshTokens,
                }),
                headers: {
                  Accept: 'application/json;charset=utf-8',
                  'Content-Type': 'application/json;charset=utf-8',
                },
              };

              fetchRetry(`${baseUrl}/auth/renew-token`, dataaaaa)
                .then(response1 => {
                  const statusCode1 = response1.status;
                  const data1 = response1.json();
                  return Promise.all([statusCode1, data1]);
                })
                .then(([statusCode1, data1]) => {
                  console.log(
                    'refresh token call and response is ',
                    statusCode1,
                    data1,
                    refreshTokens,
                  );

                  if (statusCode1 == 200) {
                    userDATA.token = data1.data.token;
                    AsyncStorage.setItem(
                      'UID_USER',
                      JSON.stringify(userDATA),
                      () => {
                        resolve(
                          fetchApi(endPoint, payload, method, headers, isS),
                        );
                      },
                    );
                  } else {
                    restartApp();
                  }
                })
                .catch(e => restartApp());
            }

            if (statusCode === 400) {
              toastMessage(data.error.message);
              clearTimeout(timeout);

              reject(data.error);
            }

            if (statusCode === 200) {
              clearTimeout(timeout);
              resolve(data.data);
            }

            if (statusCode === 201) {
              clearTimeout(timeout);
              resolve(data.data);
            }

            return data;
          })
          .catch(async e => {
            console.log('e', error.message);
            let res = await neto();
            if (e.networkError) {
              toastMessage('اشکال در اتصال اینترنت دوباره تلاش کنید .');
              Alert.alert(
                'اینترنت',
                'اشکال در اتصال اینترنت دوباره تلاش کنید .',
                [
                  {
                    text: 'تلاش مجدد',
                    onPress: () =>
                      resolve(
                        fetchApi(endPoint, payload, method, headers, isS),
                      ),
                  },
                  {text: 'بیخیال', onPress: () => reject(e)},
                ],
              );
            }
          });
      });
    });
  });
}
